@@ -31,8 +31,8 @@
 ;; Package-Requires: ((emacs "29.1"))
 ;; SPDX-License-Identifier: Apache-2.0 AND GPL-3.0-only
 ;; URL: https://codeberg.org/mekeor/nael
-;; Package-Version: 0.8.2
-;; Package-Revision: fbfb6757365c
+;; Package-Version: 20260122.1407
+;; Package-Revision: 3ee1cf286dc1
 
 ;; This is licensed under GNU General Public License (version 3 only),
 ;; see LICENSE.GPL3.  To be precise, it is licensed under Apache-2.0,
@@ -144,17 +144,11 @@
     table)
   "Syntax table used in `nael-mode'.")
 
-(defconst nael-syntax-definition-pre
-  (rx (zero-or-more (or "noncomputable" "partial" "unsafe"
-                        "private" "protected" "public" space))))
-
 (defconst nael-syntax-definition
   (rx
    ;; Use `line-start' rather than `word-start' for speed.
-   (zero-or-more line-start (regexp nael-syntax-definition-pre))
    line-start
    (group
-    (regexp nael-syntax-definition-pre)
     (or "axiom" "class" "constant" "def" "definition" "inductive"
         "instance" "lemma" "opaque" "structure" "theorem"
         (group "class" (zero-or-more space) "inductive")))
@@ -164,7 +158,7 @@
            "{" (zero-or-more (not (any "}"))) "}"
            (zero-or-more space)))
    (zero-or-more space)
-   (group-n 99 (zero-or-more (not (any " \t\n\r{([:")))))
+   (group (zero-or-more (not (any " \t\n\r{([")))))
   "Regular expression matching definitions.")
 
 (defvar nael-font-lock-defaults
@@ -194,9 +188,7 @@
           '(1 'font-lock-function-name-face))
 
     ;; Definitions:
-    (list nael-syntax-definition
-          '(1 'font-lock-keyword-face)
-          '(99 'font-lock-function-name-face))
+    nael-syntax-definition
 
     ;; Constants which have a keyword as subterm:
     (cons "∘if"
@@ -216,16 +208,16 @@
                "if" "import" "in" "include" "induction" "inductive"
                "infix" "infixl" "infixr" "init_quot" "initialize"
                "instance" "lemma" "let" "local" "macro" "macro_rules"
-               "match" "match_syntax" "module" "mut" "mutual"
-               "namespace" "nomatch" "noncomputable" "notation"
-               "open" "opaque" "partial" "postfix" "precedence"
-               "prefix" "prelude" "private" "protected" "public" "raw"
-               "rec" "register_builtin_option" "renaming" "return"
-               "run_cmd" "scoped" "section" "set_option" "show"
-               "structure" "suffices" "syntax" "then" "theorem" "this"
-               "try" "unif_hint" "universe" "universes" "unless"
-               "unsafe" "using" "using_well_founded" "variable"
-               "variables" "where" "with")
+               "match" "match_syntax" "mut" "mutual" "namespace"
+               "nomatch" "noncomputable" "notation" "open" "opaque"
+               "partial" "postfix" "precedence" "prefix" "prelude"
+               "private" "protected" "raw" "rec"
+               "register_builtin_option" "renaming" "return" "run_cmd"
+               "scoped" "section" "set_option" "show" "structure"
+               "suffices" "syntax" "then" "theorem" "this" "try"
+               "unif_hint" "universe" "universes" "unless" "unsafe"
+               "using" "using_well_founded" "variable" "variables"
+               "where" "with")
               word-end)
           'font-lock-keyword-face)
     (list (rx word-start (group "example") ".")
@@ -363,7 +355,7 @@
       (symbol-at-point))))
 
 (defvar nael-imenu-generic-expression
-  (list (list nil nael-syntax-definition 99))
+  (list (list nil nael-syntax-definition 4))
   "`imenu-generic-expression' for `nael-mode'.")
 
 ;;;; Preparation:
@@ -547,12 +539,6 @@ least evaluated an autoload statement for
 (add-to-list 'auto-mode-alist
              (cons "\\.lean\\'" 'nael-mode))
 
-(add-to-list 'project-vc-extra-root-markers
-             "lakefile.lean")
-
-(add-to-list 'project-vc-extra-root-markers
-             "lakefile.toml")
-
 (with-eval-after-load 'org-src
   (add-to-list 'org-src-lang-modes
                (cons "lean" 'nael)))
